Yesudeep Mangalapilly
Not a member
Yesudeep Mangalapilly's latest activity
Wednesday, September 16 2009
-
Yesudeep Mangalapilly created the ticket at 7:57 AMHere is some sample code:
var calendarOptions = { timePeriod: 15, showTime: true, format: "%Y-%m-%dT%H:%M:%S", fxDuration: 1 // Don't really ...
Thursday, August 06 2009
-
Yesudeep Mangalapilly commented at 3:39 PMPretty smart I'd say. I liked this part especially.
String.prototype.trim.toString().include('return'))There's always something to learn from your code.
I'm no...
Wednesday, August 05 2009
-
Yesudeep Mangalapilly commented at 1:11 AMAlso I forgot to mention.
In all the tests I ran so far, trim17 performed fastest in all WebKit based browsers
with trim16 tailing it. And I still think trim17 ... -
Yesudeep Mangalapilly commented at 1:06 AMI actually think that is a good idea but has its own share of problems.
Firefox 3.5 introduces JavaScript 1.8.1 and with it arrives a
native implementation of S...
Monday, August 03 2009
-
Yesudeep Mangalapilly commented at 5:22 AMHave updated the article comments with benchmarks on quite a few browsers
and platforms. Please see that. -
Yesudeep Mangalapilly commented at 3:43 AMAlso, if you wanted to pick something, I'd probably suggest trim13
which seems like it has consistent and quick performance across all the browsers.
Mine seems ... -
Yesudeep Mangalapilly commented at 3:23 AMOh and that's for 2000 iterations. trim17 is the one I've written.
-
Yesudeep Mangalapilly commented at 3:17 AMHere are the results:
Original length: 27662
trim10: 13ms (length: 27656)
trim11: 128ms (length: 27656)
trim12: 95ms (length: 27656)
trim13: 7ms (length: 27656)
... -
Yesudeep Mangalapilly commented at 3:06 AMI can understand that, except I'd side with including the most time-efficient function
that's available, simply because as a user of a library, I'd want to incl...
Sunday, August 02 2009
-
Yesudeep Mangalapilly created the ticket at 11:28 PMThe regular expression-based String.prototype.trim()
implementation is known to be extremely slow.
jQuery uses the same regular expression for its
implementatio...